
/*
 * slmon
 *
 * Copyright (C) 2000, 2001, 2002 Krzysztof Luks <m00se@iq.pl>
 *
 * This program is distributed under the GPL license. For details see
 * COPYING text.
 *
 * Author: Krzysztof Luks <m00se@iq.pl>
 *
 * $Date: 2002/04/01 16:16:07 $
 * $Revision: 1.8 $
 *
 */

#include "defines.h"
#include "draw.h"

void cleanup(int sig);
void close_file(FILE * f_pointer);
void init_signals(void);
void handleSIGWINCH(int signal);
void handleSIGKILL(int signal);
